@@ -2,5 +2,5 @@
 Functions and classes to help build a Fedora Service.
 '''
 
-__all__ = ('client', 'json', 'util', 'widgets',
+__all__ = ('client', 'json', 'tg1utils', 'tg2utils', 'widgets',
         'identity', 'visit')
