@@ -1,7 +1,7 @@
 #
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2008-2009  Red Hat, Inc.
+# Copyright (C) 2008-2011  Red Hat, Inc.
 # This file is part of python-fedora
 # 
 # python-fedora is free software; you can redistribute it and/or
@@ -31,6 +31,7 @@ http://en.wikipedia.org/wiki/Cross-site_request_forgery
 
 import logging
 
+from bunch import Bunch
 from kitchen.text.converters import to_bytes
 from webob import Request
 try:
@@ -81,33 +82,21 @@ class CSRFProtectionMiddleware(object):
             app = make_base_app(global_conf, wrap_app=CSRFProtectionMiddleware,
                                 full_stack=full_stack, **app_conf)
 
-    === From here on is broken ===
+    You then need to add the CSRF token to every url that you need to be
+    authenticated for.  When used with TurboGears2, an overridden version of
+    :func:`tg.url` is provided.  You can use it directly by calling::
 
-    The :class:`moksha.api.widgets.moksha:MokshaGlobals` widget then needs to
-    be rendered in every page, which automatically handles injecting the CSRF
-    token.  This widget is registerd as a Moksha Global Resource, and Moksha's
-    default index template handles injecting this by default, but you
-    can easily render Moksha's global resource injection widget in your own
-    applications template by doing the following in your master template::
+        from fedora.tg.tg2utils import url
+        [...]
+        url = url('/authentication_needed')
 
-        ${tmpl_context.moksha_global_resources()}
-
-    URLs can then be re-written using the ``moksha.csrf_rewrite_url`` function
-    that is in the ``moksha.js`` library, which is automatically pulled in by
-    the MokshaGlobals widget.  Here is an example of adding the CSRF token to
-    an ajax.  This example also utilizes the ``moksha.filter_resources``
-    function to strip out any duplicate javascript files.
-
-    .. code-block:: javascript
-
-        $.ajax({
-            url: moksha.csrf_rewrite_url('/widgets/%(id)s'),
-            success: function(data, status) {
-                var $panel = $('#%(id)s_panel');
-                var $stripped = moksha.filter_resources(data);
-                $panel.html($stripped);
-            }
-        });
+    An easier and more portable way to use that is from within TG2 to set this
+    up is to use :func:`fedora.tg.tg2utils.enable_csrf` when you setup your
+    application.  This function will monkeypatch TurboGears2's :func:`tg.url`
+    so that it adds a csrf token to urls.  This way, you can keep the same
+    code in your templates and controller methods whether or not you configure
+    the CSRF middleware to provide you with protection via
+    :func:`~fedora.tg.tg2utils.enable_csrf`.
     '''
 
     def __init__(self, application, csrf_token_id='_csrf_token',
@@ -158,6 +147,11 @@ class CSRFProtectionMiddleware(object):
             if not environ.get(self.auth_state):
                 log.debug(b_('Clearing identity'))
                 self._clean_environ(environ)
+                if 'repoze.who.identity' not in environ:
+                    environ['repoze.who.identity'] = Bunch()
+                if 'repoze.who.logins' not in environ:
+                    # For compatibility with friendlyform
+                    environ['repoze.who.logins'] = 0
                 if csrf_token:
                     log.warning(b_('Invalid CSRF token.  User supplied'
                             ' (%(u_token)s) does not match what\'s in our'
@@ -213,11 +207,14 @@ class CSRFMetadataProvider(object):
         '''
         Create the CSRF Metadata Provider Plugin.
 
-        :kwarg csrf_token_id: The name of the CSRF token variable
+        :kwarg csrf_token_id: The name of the CSRF token variable. The
+            identity will contain an entry with this as key and the
+            computed csrf_token as the value.
         :kwarg session_cookie: The name of the session cookie
         :kwarg login_handler: The path to the login handler, used to determine
             if the user logged in during this request
-        :kwarg token_env: The name of the token variable in the environ
+        :kwarg token_env: The name of the token variable in the environ.
+            The environ will contain the token from the request
         :kwarg auth_session_id: The environ key containing an optional
             session id
         :kwarg auth_state: The environ key that indicates when we are
@@ -256,6 +253,7 @@ class CSRFMetadataProvider(object):
                 to_bytes(session_id)})
 
         if session_id and session_id != 'Set-Cookie:':
+            environ[self.auth_session_id] = session_id
             token = sha1(session_id).hexdigest()
             identity.update({self.csrf_token_id: token})
             log.debug(b_('Identity updated with CSRF token'))
